@@ -3,7 +3,7 @@
 """A library that provides a Python interface to the Telegram Bots API"""
 
 __author__ = 'leandrotoledodesouza@gmail.com'
-__version__ = '2.4'
+__version__ = '2.5'
 
 from .base import TelegramObject
 from .user import User
@@ -25,6 +25,7 @@ from .replykeyboardhide import ReplyKeyboardHide
 from .forcereply import ForceReply
 from .inputfile import InputFile
 from .error import TelegramError
+from .nullhandler import NullHandler
 from .emoji import Emoji
 from .bot import Bot
 
@@ -32,4 +33,4 @@ __all__ = ['Bot', 'Emoji', 'TelegramError', 'InputFile', 'ReplyMarkup',
            'ForceReply', 'ReplyKeyboardHide', 'ReplyKeyboardMarkup',
            'UserProfilePhotos', 'ChatAction', 'Location', 'Contact',
            'Video', 'Sticker', 'Document', 'Audio', 'PhotoSize', 'GroupChat',
-           'Update', 'Message', 'User', 'TelegramObject']
+           'Update', 'Message', 'User', 'TelegramObject', 'NullHandler']
